
import pickle
import zmq

class LevelDBClient(object):

    def __init__(self, host, port):
        self.context = context = zmq.Context()
        self.socket = context.socket(zmq.REQ)
        self.socket.connect('tcp://{}:{}'.format(host, port))
    
    def _execute(self, method, key, value=b''):
        p = (method, key, value)
        self.socket.send(pickle.dumps(p))
        r = self.socket.recv()
        error, data = pickle.loads(r)
        if error:
            raise Exception(error)
        return data
    
    def _check(self, k):
        if isinstance(k, bytes):
            return k
        return pickle.dumps(k)
    
    def put(self, k, v):
        k = self._check(k)
        v = self._check(v)
        return self._execute('put', k, v)
    
    def get(self, k):
        k = self._check(k)
        return self._execute('get', k)
    
    def delete(self, k):
        k = self._check(k)
        return self._execute('delete', k)



import xmlrpc.client

class LevelDBClient(object):

    def __init__(self, server_addr):
        self.s = xmlrpc.client.ServerProxy(
            server_addr, use_builtin_types=True,
            allow_none=True
        )
    
    def _check(self, k):
        assert isinstance(k, (bytes, str)), 'Need be bytes or str'
        if isinstance(k, str):
            k = k.encode('utf-8')
        return k
    
    def put(self, k, v):
        k = self._check(k)
        v = self._check(v)
        return self.s.put(k, v)
    
    def get(self, k):
        k = self._check(k)
        return self.s.get(k)
    
    def delete(self, k):
        k = self._check(k)
        return self.s.delete(k)



#!/usr/bin/env python3
#-*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: InfinityFuture
# Mail: infinityfuture@foxmail.com
# Created Time: 2018-08-09 02:00:00
#############################################


from setuptools import setup, find_packages

setup(
    name = 'leveldbs',
    version = open('version.txt', 'r').read().strip(),
    keywords = ('pip', 'leveldb'),
    description = 'time and path tool',
    long_description = 'time and path tool',
    license = 'MIT Licence',

    url = 'https://github.com/infinityfuture/leveldb-server',
    author = 'infinityfuture',
    author_email = 'infinityfuture@foxmail.com',

    packages = find_packages(),
    include_package_data = True,
    platforms = 'any',
    install_requires = []
)